API documentation
=================

:mod:`eulfedora` -- Python objects to interact with the Fedora Commons 3.x repository

.. module:: eulfedora

.. toctree::
   :maxdepth: 2

   fedora/server
   Object and Datastream Models <fedora/models>
   Fedora API access <fedora/api>
   API XML Objects <fedora/xml>
   fedora/django
   fedora/utils


